%Copyright (c) 2016, CNRS and University of Strasbourg, France
%All rights reserved.

%Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

%1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

%2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

%3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

%THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%Author: I. Charpentier

% Reference publication
%   I. Charpentier, D. Sarocchi and L.A. Rodriguez Sedano
%   Particle shape analysis of volcanic clast samples with the Matlab tool MORPHEO
%   Computers & Geosciences 51 (2013) 172-181.

function [harmonicas,monedas7,monedas8]=barclays_monedas
close all
nbh=100;
 
%Barclays sur monedas
monedas8=[lit('monedas1.fft')];
filename=strcat('monedas1','.ray'); data=load(filename);
[npart,L]=size(data);npart=npart/2;
A=reshape(data,2,npart)
[NbPoints,L]=size(monedas8);
monedas7 = zeros(NbPoints,7); monedas7(:,1)=monedas8(:,1); monedas7(:,2:7)=monedas8(:,3:8);
mean_monedas20=monedas7(:,2);

mean_monedas8=sum(monedas8,2)/8; mean_monedas7=sum(monedas7,2)/7;
Amean=mean(monedas8,2); monedas7mean=mean(monedas7,2);

harmonicas=zeros(NbPoints,1);
y=zeros(NbPoints,1); for i=1:NbPoints,harmonicas(i)=i-1;y(i)=0.00001; end
h=figure(4);
loglog(harmonicas(2:256),mean_monedas8(2:256),'-.r',...
       harmonicas(2:256),mean_monedas20(2:256),'--g',...
       harmonicas(2:256),mean_monedas7(2:256),'-k',...
       harmonicas(2:256),y(2:256),':k'); 
   set(gca,'XLim',[1 100])
set(gca,'YLim',[1/1000000 1])
set(gca,'XTick',[1,10,100])
set(gca,'XTickLabel',{'1','10','100'})
hlegend=legend('8 coins','20 centavos','7RC','noise floor: 10^{-5}');
set(hlegend,'FontSize',12)
xlabel({'harmonics number n'},'FontSize',12);
ylabel('mean(\psi_n)','FontSize',12);

title('Coin samples','fontsize',12)
print(h,'-depsc','A_PSmonedas.eps')
end
